@@ -2,21 +2,19 @@ package OpenTracing::Implementation::NoOp::Tracer;
 
 =head1 NAME
 
-OpenTracing::Implementation::NoOp::Tracer - NoOp, so code won't break!
+OpenTracing::Implementation::NoOp::Span - NoOp, so code won't break!
 
 =head1 DESCRIPTION
 
 Objects of this class implement the required methods of the
-L<OpenTracing::Interface::Tracer>, to be compliant during testing and allow
-applications to continue working without having to catch exceptions all the
+L<OpenTracing::Interface::Scope>, to be compliant during testing and allow
+applications to continue working without having to catch acceptions all the
 time.
 
-None of the methods will do anything useful.
+None of the methods will do anything usefull.
 
 =cut
 
-our $VERSION = 'v0.72.1';
-
 
 
 use OpenTracing::Implementation::NoOp::Scope;
@@ -43,7 +41,7 @@ sub start_span {
     OpenTracing::Implementation::NoOp::Span->new( )
 }
 
-sub inject_context { $_[1] } # carrier
+sub inject_context { }
 
 sub extract_context { undef }
 
